# kapow


A python application launch framework with a punch! Kapow!

**Warning**: This alpha software currently under active development


## Installation

```bash
pip install kapow
```


```bash
poetry add kapow
```

`kapow` is a simple framework for coordinating the various pieces 
required to launch a python application. Parsing command line arguments,
reading configurations, setting up logging, deciding where those resources 
live, validating inputs are all pieces of the puzzle when an application
starts. `kapow` tries to make this process easier by providing a simple
pipline, builtin handlers and a few default setups to choose from - all while
allowing the user to customize for their particular use case. 


## kapow cli

`kapow` comes with a cli for generating a python application project. 
It is also the easiest way for the user to learn how `kapow` applications
work.


### The Basic Project

*Show an example of creqting the default basic project.*


### The Advanced Project

*Show an example of creating the default advanced project.*





